use strict;

my %species = ('NC_000964'=>'bsub.gbk',  'NC_002528'=>'buchnera.gbk', 'NC_005070'=>'cyano.gbk',
	       'NC_000913'=>'ecoli.gbk', 'NC_000908'=>'mgen.gbk', 'NC_002483'=>'plasmidf.gbk',
	       'NC_003413'=>'pyro.gbk',  'NC_001318'=>'bbur.gbk', 'NC_001416'=>'lambda.gbk');

foreach my $key (keys %species){
    next if ($key eq 'NC_002528');
    system("curl http://rest.g-language.org/togoWS/$key -o " . $species{$key});
}

